from system.clips import clips, copy, paste

from system.user import userfind, whoami

from system.xlib import xinput, xnotify, xyesno, xmsgok

from system.which import which

from system.fileage import fileage

from system.uptime import wittime
