"""init of colortext just import all usability functions"""
from colortext.colortext import \
    blu, cya, gre, grn, red, vio, whi, yel, \
    bblu, bcya, bgre, bgrn, bred, bvio, bwhi, byel, \
    tabd, tabl, tabs, abort, error, fatal
